@@ -118,10 +118,10 @@ do_ <- function() {
         url <- switch(server,
                       practice = "https://api-fxpractice.oanda.com/v3/accounts",
                       live = "https://api-fxtrade.oanda.com/v3/accounts")
-        resp <- ncurl(url, convert = FALSE, follow = TRUE,
+        resp <- ncurl(url, convert = TRUE, follow = TRUE,
                       headers = c("Authorization" = paste0("Bearer ", apikey),
                                   "User-Agent" = .user_agent))
-        parsed <- deserialize_json(resp[["raw"]])
+        parsed <- deserialize_json(resp[["data"]])
         length(parsed[["accounts"]]) || stop(parsed, call. = FALSE)
         account <<- parsed[["accounts"]][[1L]][["id"]]
       }
@@ -134,15 +134,15 @@ do_ <- function() {
         url <- paste0("https://api-fx", switch(server, practice = "practice", live = "trade"),
                       ".oanda.com/v3/accounts/", do_$getAccount(server = server, apikey = apikey),
                       "/instruments")
-        resp <- ncurl(url, convert = FALSE, follow = TRUE,
+        resp <- ncurl(url, convert = TRUE, follow = TRUE,
                       headers = c("Authorization" = paste0("Bearer ", apikey),
                                   "User-Agent" = .user_agent))
         if (resp[["status"]] != 200L) {
-          resp <- ncurl(url, convert = FALSE, follow = TRUE,
+          resp <- ncurl(url, convert = TRUE, follow = TRUE,
                         headers = c("Authorization" = paste0("Bearer ", apikey),
                                     "User-Agent" = .user_agent))
         }
-        parsed <- deserialize_json(resp[["raw"]])
+        parsed <- deserialize_json(resp[["data"]])
         length(parsed[["instruments"]]) || {
           warning(parsed,
                   "\nInstruments list could not be retrieved - falling back to internal data",
